<?php

namespace Tricks\LaravelTools\Nova\Fields;

use Laravel\Nova\Fields\Text;

class ImageAlt extends Text
{
    public function __construct($name, $attribute = null)
    {
        parent::__construct($name, $attribute);

        $this->hideFromIndex()
            ->help('Dieser Text wird angezeigt, falls das Bild nicht dargestellt wird. Zwecks Barrierefreiheit aussagekräftigen/beschreibenden Text angeben.');
    }
}
